@@ -12,10 +12,10 @@ class AsimovType(enum.Enum):
     B_NP_Nom               = -1
     B_NP_Fit               = 0
     S_NP_Fit               = 1
-    M_NP_Fit               = 2
+    S_NP_Fit_muhat         = 2
     B_unconstrained_NP_Fit = 3
     S_unconstrained_NP_Fit = 4
-    M_unconstrained_NP_Fit = 5
+    S_unconstrained_NP_Fit_muhat = 5
     
 class AsimovGenerator(AnalysisObject):
 
@@ -81,7 +81,7 @@ class AsimovGenerator(AnalysisObject):
         }
     }    
     
-    DEFAULT_ASIMOV_TYPES = [AsimovType.B_NP_Fit, AsimovType.S_NP_Fit, AsimovType.M_NP_Fit]
+    DEFAULT_ASIMOV_TYPES = [AsimovType.B_NP_Fit, AsimovType.S_NP_Fit, AsimovType.S_NP_Fit_muhat]
     
     def __init__(self, filename:str, poi_name:str=None, 
                  poi_scale:Optional[float]=None,
